netapp_ontap.resources.vscan_server_status API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.vscan_server_status`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API is used to display connection status information for the external virus-scanning servers or "Vscan servers".

## Examples

### Retrieving all fields for the Vscan server status

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Vscan

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Vscan(**{"svm.uuid": "server_status"})
        resource.get(fields="*")
        print(resource)

Try it out

    [
        Vscan(
            {
                "svm": {
                    "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/vscan/server_status/86fbc414-f140-11e8-8e22-0050568e0945/Cluster-01/10.141.46.173"
                    }
                },
            }
        ),
        Vscan(
            {
                "svm": {
                    "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/vscan/server_status/86fbc414-f140-11e8-8e22-0050568e0945/Cluster-01/fd20%3A8b1e%3Ab255%3A5053%3A%3A46%3A173"
                    }
                },
            }
        ),
    ]

### Retrieving the server status information for the server with IP address 10.141.46.173

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Vscan

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Vscan(**{"svm.uuid": "server_status"})
        resource.get(ip="10.141.46.173", fields="*")
        print(resource)

Try it out

    [
        Vscan(
            {
                "svm": {
                    "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/vscan/server_status/86fbc414-f140-11e8-8e22-0050568e0945/Cluster-01/10.141.46.173"
                    }
                },
            }
        )
    ]

## Classes

`class VscanServerStatus (*args, **kwargs)`

  Displays the connection status information of the external virus-scanning servers.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a Vscan server status.

    ### Related ONTAP commands

    - `vserver vscan connection-status show-all`

    ### Learn more

    - `DOC /protocols/vscan/server-status`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a Vscan server status.

    ### Related ONTAP commands

    - `vserver vscan connection-status show-all`

    ### Learn more

    - `DOC /protocols/vscan/server-status`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a Vscan server status.

    ### Related ONTAP commands

    - `vserver vscan connection-status show-all`

    ### Learn more

    - `DOC /protocols/vscan/server-status`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class VscanServerStatusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VscanServerStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `disconnected_reason GET POST PATCH`

    Specifies the server disconnected reason. The following is a list of the possible reasons:

    - unknown - Disconnected, unknown reason.
    - vscan_disabled - Disconnected, Vscan is disabled on the SVM.
    - no_data_lif - Disconnected, SVM does not have data LIF.
    - session_uninitialized - Disconnected, session is not initialized.
    - remote_closed - Disconnected, server has closed the connection.
    - invalid_protocol_msg - Disconnected, invalid protocol message received.
    - invalid_session_id - Disconnected, invalid session ID received.
    - inactive_connection - Disconnected, no activity on connection.
    - invalid_user - Connection request by an invalid user.
    - server_removed - Disconnected, server has been removed from the active Scanners List. enum:
    - unknown
    - vscan_disabled
    - no_data_lif
    - session_uninitialized
    - remote_closed
    - invalid_protocol_msg
    - invalid_session_id
    - inactive_connection
    - invalid_user
    - server_removed
  `ip GET POST PATCH`

    IP address of the Vscan server.

  `node GET POST PATCH`

    The node field of the vscan_server_status.

  `state GET POST PATCH`

    Specifies the server connection state indicating if it is in the connected or disconnected state. The following is a list of the possible states:

    - connected - Connected
    - disconnected - Disconnected enum:
    - connected
    - disconnected
  `svm GET POST PATCH`

    The svm field of the vscan_server_status.

  `type GET POST PATCH`

    Server type. The possible values are:

    - primary - Primary server
    - backup - Backup server

    Valid choices:

    - primary
    - backup
  `update_time GET POST PATCH`

    Specifies the time the server is in the connected or disconnected state.

  `vendor GET POST PATCH`

    Name of the connected virus-scanner vendor.

  `version GET POST PATCH`

    Version of the connected virus-scanner.